@@ -101,6 +101,7 @@
 \\tempoWholesPerMinute
 \\tempo
 \\teeny
+\\tagGroup
 \\tag
 \\table-of-contents
 \\tablatureFormat
@@ -220,6 +221,7 @@
 \\rtoe
 \\rounded-box
 \\rotate
+\\romanStringNumbers
 \\roman
 \\rightHandFinger
 \\right-column
@@ -348,6 +350,7 @@
 \\octaveCheck
 \\numericTimeSignature
 \\number
+\\nullAccidentals
 \\null
 \\notemode
 \\noteToFretFunction
@@ -460,14 +463,15 @@
 \\instrumentSwitch
 \\instrumentName
 \\instrumentEqualizer
+\\initialTimeSignatureVisibility
 \\indent
 \\include
 \\inclinatum
+\\incipit
 \\inStaffSegno
 \\in
 \\improvisationOn
 \\improvisationOff
-\\implicitTimeSignatureVisibility
 \\ij
 \\iij
 \\ignoreFiguredBassRest
@@ -521,6 +525,7 @@
 \\flat
 \\flageolet
 \\firstClef
+\\first-visible
 \\fingeringOrientations
 \\finger
 \\finalis
@@ -549,7 +554,6 @@
 \\epsfile
 \\episemInitium
 \\episemFinis
-\\endincipit
 \\enddim
 \\enddecresc
 \\enddecr
@@ -713,7 +717,13 @@
 \\backslashed-digit
 \\automaticBars
 \\autochange
+\\autoPageBreaksOn
+\\autoPageBreaksOff
+\\autoLineBreaksOn
+\\autoLineBreaksOff
 \\autoCautionaries
+\\autoBreaksOn
+\\autoBreaksOff
 \\autoBeaming
 \\autoBeamOn
 \\autoBeamOff
@@ -722,6 +732,7 @@
 \\auto-footnote
 \\augmentum
 \\auctum
+\\associatedVoiceType
 \\assertBeamSlope
 \\assertBeamQuant
 \\ascendens
@@ -733,6 +744,7 @@
 \\arpeggioArrowUp
 \\arpeggioArrowDown
 \\arpeggio
+\\arabicStringNumbers
 \\appoggiatura
 \\applyOutput
 \\applyMusic
@@ -771,11 +783,8 @@
 \\B
 \\AncientRemoveEmptyStaffContext
 \\A
-warnings
-staff
 spacing
 signature
-shift
 routine
 notes
 handler
@@ -855,6 +864,7 @@ Note_name_engraver
 Note_heads_engraver
 Note_head_line_engraver
 NoteNames
+NoteHead
 New_fingering_engraver
 Multi_measure_rest_engraver
 Midi_control_function_performer
@@ -924,7 +934,6 @@ Clef_engraver
 Chord_tremolo_engraver
 Chord_name_engraver
 ChordNames
-ChordNameVoice
 ChoirStaff
 Breathing_sign_engraver
 Break_align_engraver
@@ -1062,8 +1071,6 @@ gx
 gtqs
 gtqf
 gss
-gsharpsharp
-gsharp
 gs
 gqs
 gqf
@@ -1073,8 +1080,6 @@ gisis
 gisih
 gis
 gih
-gflatflat
-gflat
 gff
 gf
 gessess
@@ -1088,8 +1093,6 @@ fx
 ftqs
 ftqf
 fss
-fsharpsharp
-fsharp
 fs
 fqs
 fqf
@@ -1099,8 +1102,6 @@ fisis
 fisih
 fis
 fih
-fflatflat
-fflat
 fff
 ff
 fessess
@@ -1137,8 +1138,6 @@ etqs
 etqf
 essess
 ess
-esharpsharp
-esharp
 eses
 eseh
 es
@@ -1150,8 +1149,6 @@ eisis
 eisih
 eis
 eih
-eflatflat
-eflat
 eff
 ef
 eessess
@@ -1165,8 +1162,6 @@ dx
 dtqs
 dtqf
 dss
-dsharpsharp
-dsharp
 ds
 dqs
 dqf
@@ -1198,8 +1193,6 @@ disis
 disih
 dis
 dih
-dflatflat
-dflat
 dff
 df
 dessess
@@ -1213,8 +1206,6 @@ cx
 ctqs
 ctqf
 css
-csharpsharp
-csharp
 cs
 cqs
 cqf
@@ -1224,8 +1215,6 @@ cisis
 cisih
 cis
 cih
-cflatflat
-cflat
 cff
 cf
 cessess
@@ -1239,8 +1228,6 @@ bx
 btqs
 btqf
 bss
-bsharpsharp
-bsharp
 bs
 bqs
 bqf
@@ -1248,8 +1235,6 @@ bisis
 bisih
 bis
 bih
-bflatflat
-bflat
 bff
 bf
 bess
@@ -1264,8 +1249,6 @@ atqs
 atqf
 assess
 ass
-asharpsharp
-asharp
 ases
 aseh
 asas
@@ -1279,8 +1262,6 @@ aisis
 aisih
 ais
 aih
-aflatflat
-aflat
 aff
 af
 aessess
